#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2020/10/15 0015
# @Author  : justin.郑 3907721@qq.com
# @File    : cons.py
# @Desc    : 电影数据 配置文件

headers = {
    "user-agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/79.0.3945.88 Safari/537.36",
}

BOX = 'boxOffice'

MOVIE_BOX = 'http://www.cbooo.cn/%s/GetHourBoxOffice?d=%s'
