#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2020/10/13 16:57
# @Author  : justin.郑 3907721@qq.com
# @File    : cons.py.py
# @Desc    : 新经济公司 配置文件

it_headers = {
    "user-agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/79.0.3945.88 Safari/537.36",
}
it_url = "https://jfds-1252952517.cos.ap-chengdu.myqcloud.com/akshare/data/data_juzi/juzi.csv"
